@@ -86,7 +86,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -133,9 +133,22 @@
 #else
 #  define KCONFIGCORE_DEPRECATED_VERSION_5_42(text)
 #endif
+
+#if KCONFIGCORE_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text) KCONFIGCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGCORE_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KCONFIGCORE_DEPRECATED_VERSION_4(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION_5(minor, text)      KCONFIGCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGCORE_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCONFIGCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCONFIGCORE_DEPRECATED_VERSION(major, minor, text)
+#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KCONFIGCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KCONFIGCORE_EXPORT_H */
