@@ -86,7 +86,7 @@
 #define KCONFIGGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGGUI_NO_DEPRECATED
-#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KCONFIGGUI_NO_DEPRECATED_WARNINGS
 #  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -127,8 +127,21 @@
 #else
 #  define KCONFIGGUI_DEPRECATED_VERSION_5_71(text)
 #endif
+
+#if KCONFIGGUI_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KCONFIGGUI_DEPRECATED_VERSION_5_82(text) KCONFIGGUI_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGGUI_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KCONFIGGUI_DEPRECATED_VERSION_5(minor, text)      KCONFIGGUI_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGGUI_DEPRECATED_VERSION(major, minor, text) KCONFIGGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCONFIGGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGGUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KCONFIGGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCONFIGGUI_DEPRECATED_VERSION(major, minor, text)
+#  define KCONFIGGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KCONFIGGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KCONFIGGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KCONFIGGUI_EXPORT_H */
